/*
    This file is part of the KDE project, module kdesu.
    SPDX-FileCopyrightText: 1999, 2000 Geert Jansen <jansen@kde.org>

    SPDX-License-Identifier: GPL-2.0-only
*/

#ifndef KDESUDEFAULTS_H
#define KDESUDEFAULTS_H

namespace KDESu
{
const int defTimeout = 120 * 60;
const int defEchoMode = 0;
const bool defKeep = false;

}

#endif
